==> AppliStation-1.1.0-src.zip: AppliStation-1.1.0/AppliStation/AppliStation.Util/ExecutionProgressViewer.Designer.cs <==
﻿
namespace AppliStation.Util
{
	partial class ExecutionProgressViewer
	{
		/// <summary>
		/// Designer variable used to keep track of non-visual components.
		/// </summary>
		private System.ComponentModel.IContainer components = null;
		
		/// <summary>
		/// Disposes resources used by the form.
		/// </summary>
		/// <param name="disposing">true if managed resources should be disposed; otherwise, false.</param>
		protected override void Dispose(bool disposing)
		{
			if (disposing) {
				if (components != null) {
					components.Dispose();
				}
			}
			base.Dispose(disposing);
		}
		
		/// <summary>
		/// This method is required for Windows Forms designer support.
		/// Do not change the method contents inside the source code editor. The Forms designer might
		/// not be able to load this method if it was changed manually.
		/// </summary>
		private void InitializeComponent()
		{
			this.tableLayoutPanel1 = new System.Windows.Forms.TableLayoutPanel();
			this.progressSubLabel = new System.Windows.Forms.Label();
			this.subtitleLabel = new System.Windows.Forms.Label();
			this.progressBar = new System.Windows.Forms.ProgressBar();
			this.progressLabel = new System.Windows.Forms.Label();
			this.progressBarSub = new System.Windows.Forms.ProgressBar();
			this.bottomPanel = new System.Windows.Forms.FlowLayoutPanel();
			this.okButton = new System.Windows.Forms.Button();
			this.cancelButton = new System.Windows.Forms.Button();
			this.logBox = new System.Windows.Forms.RichTextBox();
			this.tableLayoutPanel1.SuspendLayout();
			this.bottomPanel.SuspendLayout();
			this.SuspendLayout();
			// 
			// tableLayoutPanel1
			// 
			this.tableLayoutPanel1.ColumnCount = 1;
			this.tableLayoutPanel1.ColumnStyles.Add(new System.Windows.Forms.ColumnStyle(System.Windows.Forms.SizeType.Percent, 100F));
			this.tableLayoutPanel1.Controls.Add(this.progressSubLabel, 0, 5);
			this.tableLayoutPanel1.Controls.Add(this.subtitleLabel, 0, 0);
			this.tableLayoutPanel1.Controls.Add(this.progressBar, 0, 1);
			this.tableLayoutPanel1.Controls.Add(this.progressLabel, 0, 2);
			this.tableLayoutPanel1.Controls.Add(this.progressBarSub, 0, 4);
			this.tableLayoutPanel1.Controls.Add(this.bottomPanel, 0, 7);
			this.tableLayoutPanel1.Controls.Add(this.logBox, 0, 6);
			this.tableLayoutPanel1.Dock = System.Windows.Forms.DockStyle.Fill;
			this.tableLayoutPanel1.Location = new System.Drawing.Point(0, 0);
			this.tableLayoutPanel1.Name = "tableLayoutPanel1";
			this.tableLayoutPanel1.RowCount = 8;
			this.tableLayoutPanel1.RowStyles.Add(new System.Windows.Forms.RowStyle(System.Windows.Forms.SizeType.Absolute, 40F));
			this.tableLayoutPanel1.RowStyles.Add(new System.Windows.Forms.RowStyle());
			this.tableLayoutPanel1.RowStyles.Add(new System.Windows.Forms.RowStyle());
			this.tableLayoutPanel1.RowStyles.Add(new System.Windows.Forms.RowStyle());
			this.tableLayoutPanel1.RowStyles.Add(new System.Windows.Forms.RowStyle());
			this.tableLayoutPanel1.RowStyles.Add(new System.Windows.Forms.RowStyle());
			this.tableLayoutPanel1.RowStyles.Add(new System.Windows.Forms.RowStyle(System.Windows.Forms.SizeType.Percent, 100F));
			this.tableLayoutPanel1.RowStyles.Add(new System.Windows.Forms.RowStyle());
			this.tableLayoutPanel1.Size = new System.Drawing.Size(444, 318);
			this.tableLayoutPanel1.TabIndex = 0;
			// 
			// progressSubLabel
			// 
			this.progressSubLabel.Dock = System.Windows.Forms.DockStyle.Fill;
			this.progressSubLabel.Location = new System.Drawing.Point(3, 118);
			this.progressSubLabel.Name = "progressSubLabel";
			this.progressSubLabel.Size = new System.Drawing.Size(438, 26);
			this.progressSubLabel.TabIndex = 6;
			this.progressSubLabel.Text = "しばらくお待ちください...";
			this.progressSubLabel.UseMnemonic = false;
			this.progressSubLabel.Visible = false;
			// 
			// subtitleLabel
			// 
			this.subtitleLabel.Dock = System.Windows.Forms.DockStyle.Bottom;
			this.subtitleLabel.Location = new System.Drawing.Point(3, 17);
			this.subtitleLabel.Name = "subtitleLabel";
			this.subtitleLabel.Size = new System.Drawing.Size(438, 23);
			this.subtitleLabel.TabIndex = 0;
			this.subtitleLabel.Text = "しばらくお待ちください...";
			this.subtitleLabel.UseMnemonic = false;
			// 
			// progressBar
			// 
			this.progressBar.Dock = System.Windows.Forms.DockStyle.Top;
			this.progressBar.Location = new System.Drawing.Point(3, 43);
			this.progressBar.Name = "progressBar";
			this.progressBar.Size = new System.Drawing.Size(438, 20);
			this.progressBar.Style = System.Windows.Forms.ProgressBarStyle.Marquee;
			this.progressBar.TabIndex = 2;
			// 
			// progressLabel
			// 
			this.progressLabel.Dock = System.Windows.Forms.DockStyle.Fill;
			this.progressLabel.Location = new System.Drawing.Point(3, 66);
			this.progressLabel.Name = "progressLabel";
			this.progressLabel.Size = new System.Drawing.Size(438, 26);
			this.progressLabel.TabIndex = 3;
			this.progressLabel.Text = "しばらくお待ちください...";
			this.progressLabel.UseMnemonic = false;
			// 
			// progressBarSub
			// 
			this.progressBarSub.Dock = System.Windows.Forms.DockStyle.Top;
			this.progressBarSub.Location = new System.Drawing.Point(3, 95);
			this.progressBarSub.Name = "progressBarSub";
			this.progressBarSub.Size = new System.Drawing.Size(438, 20);
			this.progressBarSub.Style = System.Windows.Forms.ProgressBarStyle.Continuous;
			this.progressBarSub.TabIndex = 5;
			this.progressBarSub.Visible = false;
			// 
			// bottomPanel
			// 
			this.bottomPanel.AutoSize = true;
			this.bottomPanel.Controls.Add(this.okButton);
			this.bottomPanel.Controls.Add(this.cancelButton);
			this.bottomPanel.Dock = System.Windows.Forms.DockStyle.Right;
			this.bottomPanel.Location = new System.Drawing.Point(279, 286);
			this.bottomPanel.Name = "bottomPanel";
			this.bottomPanel.Size = new System.Drawing.Size(162, 29);
			this.bottomPanel.TabIndex = 4;
			// 
			// okButton
			// 
			this.okButton.Enabled = false;
			this.okButton.Location = new System.Drawing.Point(3, 3);
			this.okButton.Name = "okButton";
			this.okButton.Size = new System.Drawing.Size(75, 23);
			this.okButton.TabIndex = 0;
			this.okButton.Text = "OK";
			this.okButton.UseVisualStyleBackColor = true;
			this.okButton.Click += new System.EventHandler(this.OkButtonClick);
			// 
			// cancelButton
			// 
			this.cancelButton.Enabled = false;
			this.cancelButton.Location = new System.Drawing.Point(84, 3);
			this.cancelButton.Name = "cancelButton";
			this.cancelButton.Size = new System.Drawing.Size(75, 23);
			this.cancelButton.TabIndex = 1;
			this.cancelButton.Text = "キャンセル";
			this.cancelButton.UseVisualStyleBackColor = true;
			this.cancelButton.Click += new System.EventHandler(this.CancelButtonClick);
			// 
			// logBox
			// 
			this.logBox.BackColor = System.Drawing.SystemColors.Control;
			this.logBox.DetectUrls = false;
			this.logBox.Dock = System.Windows.Forms.DockStyle.Fill;
			this.logBox.ForeColor = System.Drawing.SystemColors.ControlText;
			this.logBox.Location = new System.Drawing.Point(3, 147);
			this.logBox.Name = "logBox";
			this.logBox.ReadOnly = true;
			this.logBox.ScrollBars = System.Windows.Forms.RichTextBoxScrollBars.ForcedVertical;
			this.logBox.Size = new System.Drawing.Size(438, 133);
			this.logBox.TabIndex = 8;
			this.logBox.Text = "";
			// 
			// ExecutionProgressViewer
			// 
			this.AcceptButton = this.okButton;
			this.AutoScaleDimensions = new System.Drawing.SizeF(6F, 12F);
			this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
			this.ClientSize = new System.Drawing.Size(444, 318);
			this.ControlBox = false;
			this.Controls.Add(this.tableLayoutPanel1);
			this.Name = "ExecutionProgressViewer";
			this.Text = "AppliStation";
			this.Shown += new System.EventHandler(this.ExecutionProgressViewerShown);
			this.tableLayoutPanel1.ResumeLayout(false);
			this.tableLayoutPanel1.PerformLayout();
			this.bottomPanel.ResumeLayout(false);
			this.ResumeLayout(false);
		}
		private System.Windows.Forms.Button cancelButton;
		private System.Windows.Forms.Button okButton;
		private System.Windows.Forms.RichTextBox logBox;
		private System.Windows.Forms.Label progressSubLabel;
		private System.Windows.Forms.ProgressBar progressBarSub;
		private System.Windows.Forms.FlowLayoutPanel bottomPanel;
		private System.Windows.Forms.Label progressLabel;
		private System.Windows.Forms.ProgressBar progressBar;
		private System.Windows.Forms.Label subtitleLabel;
		private System.Windows.Forms.TableLayoutPanel tableLayoutPanel1;
	}
}

==> AppliStation-1.2.1a1-src.zip: AppliStation-1.2.1a1/AppliStation/AppliStation.Util/ExecutionProgressViewer.Designer.cs <==
﻿
namespace AppliStation.Util
{
	partial class ExecutionProgressViewer
	{
		/// <summary>
		/// Designer variable used to keep track of non-visual components.
		/// </summary>
		private System.ComponentModel.IContainer components = null;
		
		/// <summary>
		/// Disposes resources used by the form.
		/// </summary>
		/// <param name="disposing">true if managed resources should be disposed; otherwise, false.</param>
		protected override void Dispose(bool disposing)
		{
			if (disposing) {
				if (components != null) {
					components.Dispose();
				}
			}
			base.Dispose(disposing);
		}
		
		/// <summary>
		/// This method is required for Windows Forms designer support.
		/// Do not change the method contents inside the source code editor. The Forms designer might
		/// not be able to load this method if it was changed manually.
		/// </summary>
		private void InitializeComponent()
		{
			this.components = new System.ComponentModel.Container();
			this.tableLayoutPanel1 = new System.Windows.Forms.TableLayoutPanel();
			this.progressSubLabel = new System.Windows.Forms.Label();
			this.progressLabel = new System.Windows.Forms.Label();
			this.progressBar = new System.Windows.Forms.ProgressBar();
			this.progressBarSub = new System.Windows.Forms.ProgressBar();
			this.bottomPanel = new System.Windows.Forms.FlowLayoutPanel();
			this.autoCloseCheckBox = new System.Windows.Forms.CheckBox();
			this.okButton = new System.Windows.Forms.Button();
			this.cancelButton = new System.Windows.Forms.Button();
			this.logBox = new System.Windows.Forms.RichTextBox();
			this.autoCloseTimer = new System.Windows.Forms.Timer(this.components);
			this.toolTip = new System.Windows.Forms.ToolTip(this.components);
			this.tableLayoutPanel1.SuspendLayout();
			this.bottomPanel.SuspendLayout();
			this.SuspendLayout();
			// 
			// tableLayoutPanel1
			// 
			this.tableLayoutPanel1.ColumnCount = 1;
			this.tableLayoutPanel1.ColumnStyles.Add(new System.Windows.Forms.ColumnStyle(System.Windows.Forms.SizeType.Percent, 100F));
			this.tableLayoutPanel1.Controls.Add(this.progressSubLabel, 0, 3);
			this.tableLayoutPanel1.Controls.Add(this.progressLabel, 0, 0);
			this.tableLayoutPanel1.Controls.Add(this.progressBar, 0, 1);
			this.tableLayoutPanel1.Controls.Add(this.progressBarSub, 0, 4);
			this.tableLayoutPanel1.Controls.Add(this.bottomPanel, 0, 6);
			this.tableLayoutPanel1.Controls.Add(this.logBox, 0, 5);
			this.tableLayoutPanel1.Dock = System.Windows.Forms.DockStyle.Fill;
			this.tableLayoutPanel1.Location = new System.Drawing.Point(0, 0);
			this.tableLayoutPanel1.Name = "tableLayoutPanel1";
			this.tableLayoutPanel1.RowCount = 7;
			this.tableLayoutPanel1.RowStyles.Add(new System.Windows.Forms.RowStyle(System.Windows.Forms.SizeType.Absolute, 40F));
			this.tableLayoutPanel1.RowStyles.Add(new System.Windows.Forms.RowStyle());
			this.tableLayoutPanel1.RowStyles.Add(new System.Windows.Forms.RowStyle());
			this.tableLayoutPanel1.RowStyles.Add(new System.Windows.Forms.RowStyle());
			this.tableLayoutPanel1.RowStyles.Add(new System.Windows.Forms.RowStyle());
			this.tableLayoutPanel1.RowStyles.Add(new System.Windows.Forms.RowStyle(System.Windows.Forms.SizeType.Percent, 100F));
			this.tableLayoutPanel1.RowStyles.Add(new System.Windows.Forms.RowStyle());
			this.tableLayoutPanel1.RowStyles.Add(new System.Windows.Forms.RowStyle(System.Windows.Forms.SizeType.Absolute, 20F));
			this.tableLayoutPanel1.Size = new System.Drawing.Size(444, 318);
			this.tableLayoutPanel1.TabIndex = 0;
			// 
			// progressSubLabel
			// 
			this.progressSubLabel.Dock = System.Windows.Forms.DockStyle.Fill;
			this.progressSubLabel.Location = new System.Drawing.Point(3, 66);
			this.progressSubLabel.Name = "progressSubLabel";
			this.progressSubLabel.Size = new System.Drawing.Size(438, 26);
			this.progressSubLabel.TabIndex = 6;
			this.progressSubLabel.Text = "しばらくお待ちください...";
			this.progressSubLabel.TextAlign = System.Drawing.ContentAlignment.BottomLeft;
			this.progressSubLabel.UseMnemonic = false;
			this.progressSubLabel.Visible = false;
			// 
			// progressLabel
			// 
			this.progressLabel.Dock = System.Windows.Forms.DockStyle.Bottom;
			this.progressLabel.Font = System.Drawing.SystemFonts.CaptionFont;
			this.progressLabel.Location = new System.Drawing.Point(3, 17);
			this.progressLabel.Name = "progressLabel";
			this.progressLabel.Size = new System.Drawing.Size(438, 23);
			this.progressLabel.TabIndex = 0;
			this.progressLabel.Text = "しばらくお待ちください...";
			this.progressLabel.UseMnemonic = false;
			// 
			// progressBar
			// 
			this.progressBar.Dock = System.Windows.Forms.DockStyle.Top;
			this.progressBar.Location = new System.Drawing.Point(3, 43);
			this.progressBar.Name = "progressBar";
			this.progressBar.Size = new System.Drawing.Size(438, 20);
			this.progressBar.Style = System.Windows.Forms.ProgressBarStyle.Marquee;
			this.progressBar.TabIndex = 2;
			// 
			// progressBarSub
			// 
			this.progressBarSub.Dock = System.Windows.Forms.DockStyle.Top;
			this.progressBarSub.Location = new System.Drawing.Point(3, 95);
			this.progressBarSub.Name = "progressBarSub";
			this.progressBarSub.Size = new System.Drawing.Size(438, 20);
			this.progressBarSub.Style = System.Windows.Forms.ProgressBarStyle.Continuous;
			this.progressBarSub.TabIndex = 5;
			this.progressBarSub.Visible = false;
			// 
			// bottomPanel
			// 
			this.bottomPanel.AutoSize = true;
			this.bottomPanel.Controls.Add(this.autoCloseCheckBox);
			this.bottomPanel.Controls.Add(this.okButton);
			this.bottomPanel.Controls.Add(this.cancelButton);
			this.bottomPanel.Dock = System.Windows.Forms.DockStyle.Right;
			this.bottomPanel.Location = new System.Drawing.Point(100, 286);
			this.bottomPanel.Name = "bottomPanel";
			this.bottomPanel.Size = new System.Drawing.Size(341, 29);
			this.bottomPanel.TabIndex = 4;
			// 
			// autoCloseCheckBox
			// 
			this.autoCloseCheckBox.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Left | System.Windows.Forms.AnchorStyles.Right)));
			this.autoCloseCheckBox.AutoSize = true;
			this.autoCloseCheckBox.Checked = true;
			this.autoCloseCheckBox.CheckState = System.Windows.Forms.CheckState.Checked;
			this.autoCloseCheckBox.Location = new System.Drawing.Point(3, 6);
			this.autoCloseCheckBox.Name = "autoCloseCheckBox";
			this.autoCloseCheckBox.Size = new System.Drawing.Size(173, 16);
			this.autoCloseCheckBox.TabIndex = 2;
			this.autoCloseCheckBox.Text = "正常終了時に自動で閉じる(&A)";
			// 
			// okButton
			// 
			this.okButton.Enabled = false;
			this.okButton.Location = new System.Drawing.Point(182, 3);
			this.okButton.Name = "okButton";
			this.okButton.Size = new System.Drawing.Size(75, 23);
			this.okButton.TabIndex = 0;
			this.okButton.Text = "OK";
			this.okButton.UseVisualStyleBackColor = true;
			this.okButton.Click += new System.EventHandler(this.OkButtonClick);
			// 
			// cancelButton
			// 
			this.cancelButton.Enabled = false;
			this.cancelButton.Location = new System.Drawing.Point(263, 3);
			this.cancelButton.Name = "cancelButton";
			this.cancelButton.Size = new System.Drawing.Size(75, 23);
			this.cancelButton.TabIndex = 1;
			this.cancelButton.Text = "キャンセル";
			this.cancelButton.UseVisualStyleBackColor = true;
			this.cancelButton.Click += new System.EventHandler(this.CancelButtonClick);
			// 
			// logBox
			// 
			this.logBox.DetectUrls = false;
			this.logBox.Dock = System.Windows.Forms.DockStyle.Fill;
			this.logBox.ForeColor = System.Drawing.SystemColors.ControlText;
			this.logBox.Location = new System.Drawing.Point(3, 121);
			this.logBox.Name = "logBox";
			this.logBox.ReadOnly = true;
			this.logBox.ScrollBars = System.Windows.Forms.RichTextBoxScrollBars.ForcedVertical;
			this.logBox.Size = new System.Drawing.Size(438, 159);
			this.logBox.TabIndex = 8;
			this.logBox.Text = "";
			// 
			// autoCloseTimer
			// 
			this.autoCloseTimer.Interval = 3000;
			this.autoCloseTimer.Tick += new System.EventHandler(this.AutoCloseTimerTick);
			// 
			// ExecutionProgressViewer
			// 
			this.AcceptButton = this.okButton;
			this.AutoScaleDimensions = new System.Drawing.SizeF(6F, 12F);
			this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
			this.ClientSize = new System.Drawing.Size(444, 318);
			this.ControlBox = false;
			this.Controls.Add(this.tableLayoutPanel1);
			this.Name = "ExecutionProgressViewer";
			this.Text = "AppliStation";
			this.Shown += new System.EventHandler(this.ExecutionProgressViewerShown);
			this.FormClosed += new System.Windows.Forms.FormClosedEventHandler(this.ExecutionProgressViewerFormClosed);
			this.tableLayoutPanel1.ResumeLayout(false);
			this.tableLayoutPanel1.PerformLayout();
			this.bottomPanel.ResumeLayout(false);
			this.bottomPanel.PerformLayout();
			this.ResumeLayout(false);
		}
		private System.Windows.Forms.Label progressLabel;
		private System.Windows.Forms.ToolTip toolTip;
		private System.Windows.Forms.Timer autoCloseTimer;
		private System.Windows.Forms.CheckBox autoCloseCheckBox;
		private System.Windows.Forms.Button cancelButton;
		private System.Windows.Forms.Button okButton;
		private System.Windows.Forms.RichTextBox logBox;
		private System.Windows.Forms.Label progressSubLabel;
		private System.Windows.Forms.ProgressBar progressBarSub;
		private System.Windows.Forms.FlowLayoutPanel bottomPanel;
		private System.Windows.Forms.ProgressBar progressBar;
		private System.Windows.Forms.TableLayoutPanel tableLayoutPanel1;
	}
}
